================================
:code:`Trakt['sync/collection']`
================================

.. automodule:: trakt.interfaces.sync.collection

  .. autoclass:: SyncCollectionInterface
    :members: add, flags, get, movies, remove, shows
    :undoc-members:
